/* APP4 UART header. This implements a simple non-interrupt
   serial port.
   http://www.awce.com/app4.htm
*/
#ifndef _AWC_APP4_UART_H
#define _AWC_APP4_UART_H

// Actual baud rate is 10000000/(16*X+16) where X is a value below
// is always U2X=0

/* Use this macro to compute any odd baudrate */
#define BAUD(r) (10000000/(16*(r))-1)

/* These are common baud rates and their actual error */
#define BAUD_300 2082   // <0.1% error
#define BAUD_1200 519   // 0.2% error
#define BAUD_2400 259   // 0.2% error
#define BAUD_4800 129   // 0.2% error
#define BAUD_9600 64    // 0.2% error
#define BAUD_19200 32   // 1.4% error
#define BAUD_38400 15   // 1.7% error

/* The timeouts below are simple counters. 
   TOMULT sets how many loops count as one "tick". You can
   vary TOMULT to acheive varying delays per tick depending
   on the clock frequency */
// Timeouts are too fast at 10MHz
// so multiply by this number
#define TOMULT 200


/* Init serial port */
void UartInit(unsigned int baudrate);
/* Read a character with optional timeout (0=no timeout) */
int UartRead(unsigned int timeout);
/* Write a character with optional timeout (0=no timeout) */
int UartWrite(char c);
/* Set UART as stdio device */
void UartSetStdio(void);
/* Check to see if UART has receive data (returns non 0 if RXC is set) */
int UartReady(void);

#endif
